<form action="">
    <div class="btn-group" role="group">
        {% if cur_hit.NumberOfAssignmentsAvailable > 0 %}
        <a href="{% url 'expire_hit' cur_hit.HITId %}" role='button' id="action-expire"
           class="action btn btn-default"
           data-toggle="tooltip" title="Expire"
           data-placement="bottom" formaction=>
            <span class="glyphicon glyphicon-stop"></span>
        </a>

        <button type="submit" id="action-change-date" class="action btn btn-default" data-toggle="tooltip"
                title="Change expiration time" data-placement="bottom"
                formaction="{% url 'change_expiration' cur_hit.HITId %}"
        >

            <span class="glyphicon glyphicon-time"></span>
        </button>
        {% endif %}
        {% if cur_hit.Deletable %}
        <button type="submit" id="action-delete" class="action btn
     btn-danger
    " data-toggle="tooltip" title="Delete HIT"
                data-placement="bottom" formaction="{% url 'delete_hit' cur_hit.HITId  %}"
        >
            <span class="glyphicon glyphicon-trash"></span>
        </button>
        {% endif %}
    </div>
</form>