#slider2 {
    width: 800px;
}

.steps-2 {
    border: 1px solid transparent; /*follows #slider2 style for sizing purposes */
    width: 800px;
    position: relative;
    height: 30px;
}

.tick {
    border: 1px solid transparent; /*follows slide handle style for sizing purposes*/
    position: absolute;
    width: 1.2em;
    margin-left: -.6em;
    text-align: center;
    left: 0;
}