""" things to do in mturk module
 when a person has a session run in mturk, he should be able to manage the hit from in there:
  - sending extra bonuses;
  - manage qualifications
  - reacept rejected assignments
  - send messages

"""