{% if wrap_label %}<label{% if widget.attrs.id %} for="{{ widget.attrs.id }}"{% endif %} >{% endif %}<input type="checkbox" name="{{ widget.name }}"{% if widget.value != None %} value="{{ widget.value }}"{% endif %}  {% include "django/forms/widgets/attrs.html" %} />{% if wrap_label %} {{ widget.label }}</label>{% endif %}
