{% extends "otree_tools/BaseToolsAdmin.html" %}

{% block title %}

<code>participant.vars</code> data for the session <code>{{session.code}}</code>

{% endblock %}

{% block content %}


{%  if pvars %}
<table class="table table-hover table-striped" id="pvarstable">
    <thead>
    {% for head in heads %}
    <th>{{head}}</th>
    {%endfor%}

    </thead>
    <tbody>
    {% for p in pvars %}
    <tr>
        {% for i in p %}
        <td>{{ i }}</td>
        {% endfor %}

    </tr>
    {% endfor %}
    </tbody>
</table>
{% include 'otree_tools/includes/pagination_footer.html' %}
{% else %}
No data available.
{% endif %}
{% endblock %}

{% block internal_styles %}
{{ block.super }}
<style>
    .red {
        color: red
    }

    .green {
        color: green
    }
</style>
{% endblock %}
{% block internal_scripts %}
{{ block.super }}


{% endblock %}