/*
 * Copyright (c) 2012 Ben Olson (https://github.com/bseth99/jquery-ui-extensions)
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 */

.ui-slider-wrapper {
    position: relative;
}

.ui-slider-wrapper .ui-slider-horizontal {
    width: 100%;
}

.ui-slider-labels {
    position: absolute;
    border: 1px solid transparent;
}

.ui-slider-label-ticks {
    border: 1px solid transparent;
    position: absolute;
    white-space: nowrap;
}

.ui-slider-label-ticks span {
    font-size: 0.9em;
    min-width: 1.2em;
}

.ui-slider-wrapper.horizontal {
    height: 4.5em;
}

.horizontal .ui-slider-labels {
    left: 0;
    right: 0;
    top: 0.7em
}

.horizontal .ui-slider-label-ticks {
    width: 1.2em;
    height: .8em;
    text-align: center;
    border-left: 1px solid #999;
}

.horizontal .ui-slider-label-ticks span {
    position: relative;
    display: inline-block;
    margin-left: -1.2em;
    top: .8em;
}

.bold-tick {
     border-left: 1.2px solid black!important;
}

.ui-slider-wrapper.vertical {
    width: 4.5em;
}

.vertical .ui-slider-labels {
    top: 1px;
    bottom: 0;
    left: 0.7em;
}

.vertical .ui-slider-label-ticks {
    height: 1.2em;
    width: 0.8em;
    border-bottom: 1px solid #999;
}

.vertical .ui-slider-label-ticks span {
    position: relative;
    display: inline-block;
    margin-left: 1em;
    top: .6em;
}

.ui-slider .ui-slider-handle {
    /*height: 150px;*/
    /*width: 5px;*/
    /*padding-left: 5px;*/
}